@@ -198,18 +198,6 @@ class QuicTransportBase : public QuicSocket,
       bool eof,
       ByteEventCallback* cb = nullptr) override;
 
-  // TODO: Maybe I should virtualize DSR related APIs and only implement in
-  // QuicServerTransport
-  WriteResult writeBufMeta(
-      StreamId id,
-      const BufferMeta& data,
-      bool eof,
-      ByteEventCallback* cb = nullptr) override;
-
-  WriteResult setDSRPacketizationRequestSender(
-      StreamId id,
-      std::unique_ptr<DSRPacketizationRequestSender> sender) override;
-
   folly::Expected<folly::Unit, LocalErrorCode> registerDeliveryCallback(
       StreamId id,
       uint64_t offset,
@@ -1027,6 +1015,18 @@ class QuicTransportBase : public QuicSocket,
   void onSocketWritable() noexcept override;
   void maybeStopWriteLooperAndArmSocketWritableEvent();
 
+  /**
+   * Checks the idle timer on write events, and if it's past the idle timeout,
+   * calls the timer finctions.
+   */
+  void checkIdleTimer(TimePoint now);
+  struct IdleTimeoutCheck {
+    std::chrono::milliseconds idleTimeoutMs{0};
+    Optional<TimePoint> lastTimeIdleTimeoutScheduled_;
+    bool forcedIdleTimeoutScheduled_{false};
+  };
+  IdleTimeoutCheck idleTimeoutCheck_;
+
  private:
   /**
    * Helper functions to handle new streams.
