@@ -14,6 +14,7 @@
 #include <quic/codec/QuicPacketBuilder.h>
 #include <quic/codec/QuicWriteCodec.h>
 #include <quic/codec/Types.h>
+#include <quic/common/BufAccessor.h>
 #include <quic/flowcontrol/QuicFlowController.h>
 #include <quic/happyeyeballs/QuicHappyEyeballsFunctions.h>
 
@@ -30,13 +31,13 @@ namespace {
  */
 bool cryptoHasWritableData(const quic::QuicConnectionStateBase& conn) {
   return (conn.initialWriteCipher &&
-          (!conn.cryptoState->initialStream.writeBuffer.empty() ||
+          (!conn.cryptoState->initialStream.pendingWrites.empty() ||
            !conn.cryptoState->initialStream.lossBuffer.empty())) ||
       (conn.handshakeWriteCipher &&
-       (!conn.cryptoState->handshakeStream.writeBuffer.empty() ||
+       (!conn.cryptoState->handshakeStream.pendingWrites.empty() ||
         !conn.cryptoState->handshakeStream.lossBuffer.empty())) ||
       (conn.oneRttWriteCipher &&
-       (!conn.cryptoState->oneRttStream.writeBuffer.empty() ||
+       (!conn.cryptoState->oneRttStream.pendingWrites.empty() ||
         !conn.cryptoState->oneRttStream.lossBuffer.empty()));
 }
 
@@ -231,14 +232,11 @@ DataPathResult continuousMemoryBuildScheduleEncrypt(
     IOBufQuicBatch& ioBufBatch,
     const Aead& aead,
     const PacketNumberCipher& headerCipher) {
-  auto buf = connection.bufAccessor->obtain();
-  auto prevSize = buf->length();
-  connection.bufAccessor->release(std::move(buf));
+  auto prevSize = connection.bufAccessor->length();
 
   auto rollbackBuf = [&]() {
-    auto buf = connection.bufAccessor->obtain();
-    buf->trimEnd(buf->length() - prevSize);
-    connection.bufAccessor->release(std::move(buf));
+    connection.bufAccessor->trimEnd(
+        connection.bufAccessor->length() - prevSize);
   };
 
   // It's the scheduler's job to invoke encode header
@@ -272,16 +270,17 @@ DataPathResult continuousMemoryBuildScheduleEncrypt(
   }
   CHECK(!packet->header.isChained());
   auto headerLen = packet->header.length();
-  buf = connection.bufAccessor->obtain();
   CHECK(
-      packet->body.data() > buf->data() && packet->body.tail() <= buf->tail());
+      packet->body.data() > connection.bufAccessor->data() &&
+      packet->body.tail() <= connection.bufAccessor->tail());
   CHECK(
-      packet->header.data() >= buf->data() &&
-      packet->header.tail() < buf->tail());
+      packet->header.data() >= connection.bufAccessor->data() &&
+      packet->header.tail() < connection.bufAccessor->tail());
   // Trim off everything before the current packet, and the header length, so
   // buf's data starts from the body part of buf.
-  buf->trimStart(prevSize + headerLen);
+  connection.bufAccessor->trimStart(prevSize + headerLen);
   // buf and packetBuf is actually the same.
+  auto buf = connection.bufAccessor->obtain();
   auto packetBuf =
       aead.inplaceEncrypt(std::move(buf), &packet->header, packetNum);
   CHECK(packetBuf->headroom() == headerLen + prevSize);
@@ -416,8 +415,9 @@ void handleNewStreamDataWritten(
   // Idealy we should also check this data doesn't exist in either retx buffer
   // or loss buffer, but that's an expensive search.
   stream.currentWriteOffset += frameLen;
-  auto bufWritten = stream.writeBuffer.splitAtMost(folly::to<size_t>(frameLen));
-  DCHECK_EQ(bufWritten->computeChainDataLength(), frameLen);
+  ChainedByteRangeHead bufWritten(
+      stream.pendingWrites.splitAtMost(folly::to<size_t>(frameLen)));
+  DCHECK_EQ(bufWritten.chainLength(), frameLen);
   // TODO: If we want to be able to write FIN out of order for DSR-ed streams,
   // this needs to be fixed:
   stream.currentWriteOffset += frameFin ? 1 : 0;
@@ -425,7 +425,7 @@ void handleNewStreamDataWritten(
             .emplace(
                 std::piecewise_construct,
                 std::forward_as_tuple(originalOffset),
-                std::forward_as_tuple(std::make_unique<StreamBuffer>(
+                std::forward_as_tuple(std::make_unique<WriteStreamBuffer>(
                     std::move(bufWritten), originalOffset, frameFin)))
             .second);
 }
@@ -457,24 +457,30 @@ void handleRetransmissionWritten(
     uint64_t frameOffset,
     uint64_t frameLen,
     bool frameFin,
-    CircularDeque<StreamBuffer>::iterator lossBufferIter) {
+    CircularDeque<WriteStreamBuffer>::iterator lossBufferIter) {
   auto bufferLen = lossBufferIter->data.chainLength();
-  Buf bufWritten;
   if (frameLen == bufferLen && frameFin == lossBufferIter->eof) {
     // The buffer is entirely retransmitted
-    bufWritten = lossBufferIter->data.move();
+    ChainedByteRangeHead bufWritten(std::move(lossBufferIter->data));
     stream.lossBuffer.erase(lossBufferIter);
+    CHECK(stream.retransmissionBuffer
+              .emplace(
+                  std::piecewise_construct,
+                  std::forward_as_tuple(frameOffset),
+                  std::forward_as_tuple(std::make_unique<WriteStreamBuffer>(
+                      std::move(bufWritten), frameOffset, frameFin)))
+              .second);
   } else {
     lossBufferIter->offset += frameLen;
-    bufWritten = lossBufferIter->data.splitAtMost(frameLen);
+    ChainedByteRangeHead bufWritten(lossBufferIter->data.splitAtMost(frameLen));
+    CHECK(stream.retransmissionBuffer
+              .emplace(
+                  std::piecewise_construct,
+                  std::forward_as_tuple(frameOffset),
+                  std::forward_as_tuple(std::make_unique<WriteStreamBuffer>(
+                      std::move(bufWritten), frameOffset, frameFin)))
+              .second);
   }
-  CHECK(stream.retransmissionBuffer
-            .emplace(
-                std::piecewise_construct,
-                std::forward_as_tuple(frameOffset),
-                std::forward_as_tuple(std::make_unique<StreamBuffer>(
-                    std::move(bufWritten), frameOffset, frameFin)))
-            .second);
 }
 
 void handleRetransmissionBufMetaWritten(
@@ -1627,9 +1633,9 @@ WriteQuicDataResult writeConnectionDataToSocket(
   if (connection.transportSettings.dataPathType ==
       DataPathType::ContinuousMemory) {
     CHECK(connection.bufAccessor->ownsBuffer());
-    auto buf = connection.bufAccessor->obtain();
-    CHECK(buf->length() == 0 && buf->headroom() == 0);
-    connection.bufAccessor->release(std::move(buf));
+    CHECK(
+        connection.bufAccessor->length() == 0 &&
+        connection.bufAccessor->headroom() == 0);
   }
   return {ioBufBatch.getPktSent(), 0, bytesWritten};
 }
@@ -1900,7 +1906,7 @@ void implicitAckCryptoStream(
   cryptoStream->lossBuffer.clear();
   CHECK(cryptoStream->retransmissionBuffer.empty());
   // The write buffer should be empty, there's no optional crypto data.
-  CHECK(cryptoStream->writeBuffer.empty());
+  CHECK(cryptoStream->pendingWrites.empty());
 }
 
 void handshakeConfirmed(QuicConnectionStateBase& conn) {
