@@ -869,6 +869,20 @@ void QuicClientTransport::onReadData(
   maybeSendTransportKnobs();
 }
 
+QuicSocket::WriteResult QuicClientTransport::writeBufMeta(
+    StreamId /* id */,
+    const BufferMeta& /* data */,
+    bool /* eof */,
+    ByteEventCallback* /* cb */) {
+  return folly::makeUnexpected(LocalErrorCode::INVALID_OPERATION);
+}
+
+QuicSocket::WriteResult QuicClientTransport::setDSRPacketizationRequestSender(
+    StreamId /* id */,
+    std::unique_ptr<DSRPacketizationRequestSender> /* sender */) {
+  return folly::makeUnexpected(LocalErrorCode::INVALID_OPERATION);
+}
+
 void QuicClientTransport::writeData() {
   QuicVersion version = conn_->version.value_or(*conn_->originalVersion);
   const ConnectionId& srcConnId = *conn_->clientConnectionId;
@@ -1218,6 +1232,12 @@ void QuicClientTransport::recvMsg(
       }
     }
 #endif
+    ReceivedUdpPacket::Timings timings;
+    if (params.ts.has_value()) {
+      timings.maybeSoftwareTs =
+          QuicAsyncUDPSocket::convertToSocketTimestampExt(*params.ts);
+    }
+
     size_t bytesRead = size_t(ret);
     totalData += bytesRead;
     if (!server) {
@@ -1245,21 +1265,21 @@ void QuicClientTransport::recvMsg(
 
           offset += params.gro;
           remaining -= params.gro;
-          networkData.addPacket(ReceivedUdpPacket(
-              std::move(tmp), ReceivedUdpPacket::Timings{}, params.tos));
+          networkData.addPacket(
+              ReceivedUdpPacket(std::move(tmp), timings, params.tos));
         } else {
           // do not clone the last packet
           // start at offset, use all the remaining data
           readBuffer->trimStart(offset);
           DCHECK_EQ(readBuffer->length(), remaining);
           remaining = 0;
-          networkData.addPacket(ReceivedUdpPacket(
-              std::move(readBuffer), ReceivedUdpPacket::Timings{}, params.tos));
+          networkData.addPacket(
+              ReceivedUdpPacket(std::move(readBuffer), timings, params.tos));
         }
       }
     } else {
-      networkData.addPacket(ReceivedUdpPacket(
-          std::move(readBuffer), ReceivedUdpPacket::Timings{}, params.tos));
+      networkData.addPacket(
+          ReceivedUdpPacket(std::move(readBuffer), timings, params.tos));
     }
     maybeQlogDatagram(bytesRead);
   }
@@ -1374,6 +1394,12 @@ void QuicClientTransport::recvMmsg(
       server->setFromSockaddr(rawAddr, kAddrLen);
     }
 
+    ReceivedUdpPacket::Timings timings;
+    if (params.ts.has_value()) {
+      timings.maybeSoftwareTs =
+          QuicAsyncUDPSocket::convertToSocketTimestampExt(*params.ts);
+    }
+
     VLOG(10) << "Got data from socket peer=" << *server << " len=" << bytesRead;
     readBuffer->append(bytesRead);
     if (params.gro > 0) {
@@ -1395,21 +1421,21 @@ void QuicClientTransport::recvMmsg(
 
           offset += params.gro;
           remaining -= params.gro;
-          networkData.addPacket(ReceivedUdpPacket(
-              std::move(tmp), ReceivedUdpPacket::Timings{}, params.tos));
+          networkData.addPacket(
+              ReceivedUdpPacket(std::move(tmp), timings, params.tos));
         } else {
           // do not clone the last packet
           // start at offset, use all the remaining data
           readBuffer->trimStart(offset);
           DCHECK_EQ(readBuffer->length(), remaining);
           remaining = 0;
-          networkData.addPacket(ReceivedUdpPacket(
-              std::move(readBuffer), ReceivedUdpPacket::Timings{}, params.tos));
+          networkData.addPacket(
+              ReceivedUdpPacket(std::move(readBuffer), timings, params.tos));
         }
       }
     } else {
-      networkData.addPacket(ReceivedUdpPacket(
-          std::move(readBuffer), ReceivedUdpPacket::Timings{}, params.tos));
+      networkData.addPacket(
+          ReceivedUdpPacket(std::move(readBuffer), timings, params.tos));
     }
 
     maybeQlogDatagram(bytesRead);
