@@ -52,27 +52,27 @@ class MockClientHandshake : public ClientHandshake {
       bool,
       verifyRetryIntegrityTag,
       (const ConnectionId&, const RetryPacket&));
-  MOCK_METHOD(void, removePsk, (const folly::Optional<std::string>&));
+  MOCK_METHOD(void, removePsk, (const Optional<std::string>&));
   MOCK_METHOD(const CryptoFactory&, getCryptoFactory, (), (const));
   MOCK_METHOD(bool, isTLSResumed, (), (const));
   MOCK_METHOD(
-      folly::Optional<std::vector<uint8_t>>,
+      Optional<std::vector<uint8_t>>,
       getExportedKeyingMaterial,
       (const std::string& label,
-       const folly::Optional<folly::ByteRange>& context,
+       const Optional<folly::ByteRange>& context,
        uint16_t keyLength),
       ());
-  MOCK_METHOD(folly::Optional<bool>, getZeroRttRejected, ());
+  MOCK_METHOD(Optional<bool>, getZeroRttRejected, ());
   MOCK_METHOD(
-      const folly::Optional<ServerTransportParameters>&,
+      const Optional<ServerTransportParameters>&,
       getServerTransportParams,
       ());
   MOCK_METHOD(void, destroy, ());
 
   MOCK_METHOD(
-      folly::Optional<CachedServerTransportParameters>,
+      Optional<CachedServerTransportParameters>,
       connectImpl,
-      (folly::Optional<std::string>));
+      (Optional<std::string>));
   MOCK_METHOD(EncryptionLevel, getReadRecordLayerEncryptionLevel, ());
   MOCK_METHOD(void, processSocketData, (folly::IOBufQueue & queue));
   MOCK_METHOD(bool, matchEarlyParameters, ());
@@ -86,7 +86,7 @@ class MockClientHandshake : public ClientHandshake {
       (folly::ByteRange secret));
   MOCK_METHOD(Buf, getNextTrafficSecret, (folly::ByteRange secret), (const));
   MOCK_METHOD(
-      const folly::Optional<std::string>&,
+      const Optional<std::string>&,
       getApplicationProtocol,
       (),
       (const));
