@@ -40,7 +40,10 @@ constexpr float kBeta = 0.7;
 constexpr float kLossThreshold = 0.02;
 constexpr float kHeadroomFactor = 0.15;
 
-quic::Bandwidth kMinPacingRateForSendQuantum{1200 * 1000, 1s};
+#ifndef CLANG_LAZY_INIT
+#define CLANG_LAZY_INIT
+#endif
+CLANG_LAZY_INIT quic::Bandwidth kMinPacingRateForSendQuantum{1200 * 1000, 1s};
 // The experimental pacer currently achieves ~99% of the target rate
 // we should not reduce the target by adding an extra margin.
 // TODO: add the margin back if the pacer performance improves further.
@@ -249,6 +252,11 @@ void Bbr2CongestionController::enterStartup() {
 }
 
 void Bbr2CongestionController::setPacing() {
+  if (!conn_.transportSettings.ccaConfig.paceInitCwnd &&
+      conn_.lossState.totalBytesSent <
+          conn_.transportSettings.initCwndInMss * conn_.udpSendPacketLen) {
+    return;
+  }
   uint64_t pacingWindow =
       bandwidth_ * minRtt_ * pacingGain_ * (100 - kPacingMarginPercent) / 100;
   VLOG(6) << "Setting pacing to "
