@@ -62,7 +62,7 @@ TEST_F(BbrTest, Recovery) {
   conn.transportSettings.initCwndInMss = 500; // Make a really large initCwnd
   BbrCongestionController bbr(conn);
   // Make a huge inflight so we don't underflow anything
-  auto inflightBytes = 100 * 1000;
+  auto inflightBytes = std::numeric_limits<uint16_t>::max();
   bbr.onPacketSent(makeTestingWritePacket(9, inflightBytes, inflightBytes));
 
   // This also makes sure recoveryWindow_ is larger than inflightBytes
@@ -106,7 +106,7 @@ TEST_F(BbrTest, Recovery) {
   // This doesn't change endOfRoundTrip_, but move endOfRecovery to new
   // Clock::now()
   auto estimatedLossTime = Clock::now();
-  bbr.onPacketAckOrLoss(folly::none, loss2);
+  bbr.onPacketAckOrLoss(none, loss2);
   EXPECT_EQ(expectedRecoveryWindow, bbr.getCongestionWindow());
 
   ackedBytes = 500;
@@ -118,7 +118,7 @@ TEST_F(BbrTest, Recovery) {
           ackedBytes,
           estimatedLossTime - 1us,
           estimatedEndOfRoundTrip + 1us),
-      folly::none);
+      none);
   EXPECT_TRUE(bbr.inRecovery());
   // Since recoveryWindow_ is larger than inflightBytes + recoveryIncrase
   EXPECT_EQ(expectedRecoveryWindow, bbr.getCongestionWindow());
@@ -128,13 +128,13 @@ TEST_F(BbrTest, Recovery) {
   loss3.persistentCongestion = true;
   loss3.lostBytes = inflightBytes / 2;
   expectedRecoveryWindow = conn.udpSendPacketLen * kMinCwndInMssForBbr;
-  bbr.onPacketAckOrLoss(folly::none, loss3);
+  bbr.onPacketAckOrLoss(none, loss3);
   EXPECT_EQ(expectedRecoveryWindow, bbr.getCongestionWindow());
 
   CongestionController::AckEvent ack3 = makeAck(
       12, inflightBytes / 2, estimatedLossTime + 10ms, estimatedLossTime + 5ms);
   // This will exit Recovery
-  bbr.onPacketAckOrLoss(ack3, folly::none);
+  bbr.onPacketAckOrLoss(ack3, none);
   EXPECT_FALSE(bbr.inRecovery());
   // Only one update should have been issued.
   ASSERT_EQ(conn.pendingEvents.frames.size(), 1);
@@ -166,7 +166,7 @@ TEST_F(BbrTest, StartupCwnd) {
   // Target cwnd will be 100 * 5000 * 2.885 = 1442500, but you haven't finished
   // STARTUP, too bad kiddo, you only grow a little today
   bbr.onPacketAckOrLoss(
-      makeAck(0, 3000, Clock::now(), packet.metadata.time), folly::none);
+      makeAck(0, 3000, Clock::now(), packet.metadata.time), none);
   EXPECT_EQ(startingCwnd + 3000, bbr.getCongestionWindow());
 }
 
@@ -194,7 +194,7 @@ TEST_F(BbrTest, StartupCwndImplicit) {
   // STARTUP, too bad kiddo, you only grow a little today
   auto ack = makeAck(0, 3000, Clock::now(), packet.metadata.time);
   ack.implicit = true;
-  bbr.onPacketAckOrLoss(ack, folly::none);
+  bbr.onPacketAckOrLoss(ack, none);
   EXPECT_EQ(startingCwnd + 3000, bbr.getCongestionWindow());
 }
 
@@ -222,8 +222,7 @@ TEST_F(BbrTest, LeaveStartup) {
         .WillRepeatedly(Return(
             mockedBandwidth * (growFast ? kExpectedStartupGrowth : 1.0)));
     bbr.onPacketAckOrLoss(
-        makeAck(currentLatest, 1000, Clock::now(), packet.metadata.time),
-        folly::none);
+        makeAck(currentLatest, 1000, Clock::now(), packet.metadata.time), none);
     conn.lossState.totalBytesAcked += 1000;
     if (growFast) {
       mockedBandwidth = mockedBandwidth * kExpectedStartupGrowth;
@@ -309,7 +308,7 @@ TEST_F(BbrTest, ProbeRtt) {
           conn.udpSendPacketLen,
           Clock::now(),
           packetToAck.second),
-      folly::none);
+      none);
   conn.lossState.totalBytesAcked += conn.udpSendPacketLen;
   inflightBytes -= conn.udpSendPacketLen;
   inflightPackets.pop_front();
@@ -327,7 +326,7 @@ TEST_F(BbrTest, ProbeRtt) {
           conn.udpSendPacketLen,
           Clock::now(),
           packetToAck.second),
-      folly::none);
+      none);
   conn.lossState.totalBytesAcked += conn.udpSendPacketLen;
   inflightBytes -= conn.udpSendPacketLen;
   inflightPackets.pop_front();
@@ -344,7 +343,7 @@ TEST_F(BbrTest, ProbeRtt) {
             conn.udpSendPacketLen,
             Clock::now(),
             packetToAck.second),
-        folly::none);
+        none);
     conn.lossState.totalBytesAcked += conn.udpSendPacketLen;
     inflightBytes -= conn.udpSendPacketLen;
     inflightPackets.pop_front();
@@ -361,7 +360,7 @@ TEST_F(BbrTest, ProbeRtt) {
           conn.udpSendPacketLen,
           currentTime,
           packetToAck.second),
-      folly::none);
+      none);
   conn.lossState.totalBytesAcked += conn.udpSendPacketLen;
   inflightBytes -= conn.udpSendPacketLen;
   inflightPackets.pop_front();
@@ -376,7 +375,7 @@ TEST_F(BbrTest, ProbeRtt) {
             conn.udpSendPacketLen,
             packetToAck.second + 1ms,
             packetToAck.second),
-        folly::none);
+        none);
     inflightBytes -= conn.udpSendPacketLen;
     inflightPackets.pop_front();
     EXPECT_EQ(BbrCongestionController::BbrState::ProbeRtt, bbr.state());
@@ -393,7 +392,7 @@ TEST_F(BbrTest, ProbeRtt) {
           conn.udpSendPacketLen,
           packetToAck.second + 2ms,
           packetToAck.second),
-      folly::none);
+      none);
   inflightBytes -= conn.udpSendPacketLen;
   inflightPackets.pop_front();
   EXPECT_EQ(BbrCongestionController::BbrState::ProbeRtt, bbr.state());
@@ -411,7 +410,7 @@ TEST_F(BbrTest, ProbeRtt) {
           conn.udpSendPacketLen,
           packetToAck.second + kProbeRttDuration,
           packetToAck.second),
-      folly::none);
+      none);
   conn.lossState.totalBytesAcked += conn.udpSendPacketLen;
   inflightBytes -= conn.udpSendPacketLen;
   inflightPackets.pop_front();
@@ -557,7 +556,7 @@ TEST_F(BbrTest, AckAggregation) {
             // force send time < ack time
             Clock::now() + std::chrono::milliseconds(10),
             packet.metadata.time),
-        folly::none);
+        none);
     conn.lossState.totalBytesAcked += 1000;
     if (growFast) {
       mockedBandwidth = mockedBandwidth * kExpectedStartupGrowth;
@@ -603,7 +602,7 @@ TEST_F(BbrTest, AckAggregation) {
       .WillRepeatedly(Return(mockedBandwidth * 10));
   auto expectedBdp =
       mockedBandwidth * 50 * std::chrono::microseconds(50) / 1000 / 1000;
-  bbr.onPacketAckOrLoss(ackEvent, folly::none);
+  bbr.onPacketAckOrLoss(ackEvent, none);
   auto newCwnd = bbr.getCongestionWindow();
   auto currentMaxAckHeight = 0;
   if (newCwnd != currentCwnd + 1000) {
@@ -626,7 +625,7 @@ TEST_F(BbrTest, AckAggregation) {
       ackEvent.ackTime + 1ms,
       packet1.metadata.time);
 
-  bbr.onPacketAckOrLoss(ackEvent2, folly::none);
+  bbr.onPacketAckOrLoss(ackEvent2, none);
   newCwnd = bbr.getCongestionWindow();
   EXPECT_GT(newCwnd, expectedBdp * kProbeBwGain + currentMaxAckHeight);
 }
@@ -695,7 +694,7 @@ TEST_F(BbrTest, ExtendMinRttExpiration) {
           1000,
           Clock::now(),
           packet.metadata.time),
-      folly::none);
+      none);
 }
 
 TEST_F(BbrTest, BytesCounting) {
@@ -753,7 +752,7 @@ TEST_F(BbrTest, PacketLossInvokesPacer) {
   EXPECT_CALL(*rawPacer, onPacketsLoss()).Times(1);
   CongestionController::LossEvent lossEvent;
   lossEvent.addLostPacket(packet);
-  bbr.onPacketAckOrLoss(folly::none, lossEvent);
+  bbr.onPacketAckOrLoss(none, lossEvent);
 }
 
 TEST_F(BbrTest, ProbeRttSetsAppLimited) {
@@ -770,13 +769,13 @@ TEST_F(BbrTest, ProbeRttSetsAppLimited) {
   EXPECT_CALL(*rawRttSampler, minRttExpired()).Times(1).WillOnce(Return(true));
   EXPECT_CALL(*rawBandwidthSampler, onAppLimited()).Times(2);
   bbr.onPacketAckOrLoss(
-      makeAck(0, 1000, Clock::now(), Clock::now() - 5ms), folly::none);
+      makeAck(0, 1000, Clock::now(), Clock::now() - 5ms), none);
   EXPECT_EQ(BbrCongestionController::BbrState::ProbeRtt, bbr.state());
 
   bbr.onPacketSent(makeTestingWritePacket(1, 1000, 2000));
   EXPECT_CALL(*rawBandwidthSampler, onAppLimited()).Times(1);
   bbr.onPacketAckOrLoss(
-      makeAck(1, 1000, Clock::now(), Clock::now() - 5ms), folly::none);
+      makeAck(1, 1000, Clock::now(), Clock::now() - 5ms), none);
   EXPECT_EQ(BbrCongestionController::BbrState::ProbeRtt, bbr.state());
 }
 
