@@ -30,7 +30,6 @@ CongestionController::LossEvent createLossEvent(
         Clock::now(),
         10,
         0,
-        false,
         10,
         0,
         LossState(),
@@ -64,7 +63,6 @@ CongestionController::AckEvent createAckEvent(
           packetSentTime,
           ackedSize,
           0,
-          false,
           ackedSize,
           0,
           LossState(),
@@ -86,7 +84,6 @@ OutstandingPacketWrapper createPacket(
       sendTime,
       size,
       0,
-      false,
       size,
       inflight,
       LossState(),
@@ -113,22 +110,19 @@ TEST_F(NewRenoTest, TestLoss) {
   EXPECT_EQ(reno.getBytesInFlight(), 41);
   auto originalWritableBytes = reno.getWritableBytes();
 
-  reno.onPacketAckOrLoss(
-      folly::none, createLossEvent({std::make_pair(loss1, 11)}));
+  reno.onPacketAckOrLoss(none, createLossEvent({std::make_pair(loss1, 11)}));
   EXPECT_EQ(reno.getBytesInFlight(), 30);
 
   EXPECT_FALSE(reno.inSlowStart());
   auto newWritableBytes1 = reno.getWritableBytes();
   EXPECT_LE(newWritableBytes1, originalWritableBytes + 11);
 
-  reno.onPacketAckOrLoss(
-      folly::none, createLossEvent({std::make_pair(loss2, 10)}));
+  reno.onPacketAckOrLoss(none, createLossEvent({std::make_pair(loss2, 10)}));
   auto newWritableBytes2 = reno.getWritableBytes();
   EXPECT_LE(newWritableBytes2, newWritableBytes1 + 10);
   EXPECT_EQ(reno.getBytesInFlight(), 20);
 
-  reno.onPacketAckOrLoss(
-      folly::none, createLossEvent({std::make_pair(loss3, 20)}));
+  reno.onPacketAckOrLoss(none, createLossEvent({std::make_pair(loss3, 20)}));
   auto newWritableBytes3 = reno.getWritableBytes();
   EXPECT_LE(newWritableBytes3, newWritableBytes2 + 20);
   EXPECT_EQ(reno.getBytesInFlight(), 0);
@@ -147,7 +141,7 @@ TEST_F(NewRenoTest, SendMoreThanWritable) {
   EXPECT_EQ(reno.getBytesInFlight(), originalWritableBytes + 20);
   EXPECT_EQ(reno.getWritableBytes(), 0);
   reno.onPacketAckOrLoss(
-      folly::none,
+      none,
       createLossEvent({std::make_pair(loss, originalWritableBytes + 20)}));
   EXPECT_LT(reno.getWritableBytes(), originalWritableBytes);
 }
@@ -166,8 +160,7 @@ TEST_F(NewRenoTest, TestSlowStartAck) {
   reno.onPacketSent(packet);
   EXPECT_EQ(reno.getBytesInFlight(), ackedSize);
   reno.onPacketAckOrLoss(
-      createAckEvent(ackPacketNum1, ackedSize, packet.metadata.time),
-      folly::none);
+      createAckEvent(ackPacketNum1, ackedSize, packet.metadata.time), none);
   EXPECT_TRUE(reno.inSlowStart());
   auto newWritableBytes = reno.getWritableBytes();
 
@@ -184,8 +177,7 @@ TEST_F(NewRenoTest, TestSteadyStateAck) {
   auto originalWritableBytes = reno.getWritableBytes();
   PacketNum loss1 = 4;
   reno.onPacketSent(createPacket(loss1, 10, Clock::now()));
-  reno.onPacketAckOrLoss(
-      folly::none, createLossEvent({std::make_pair(loss1, 10)}));
+  reno.onPacketAckOrLoss(none, createLossEvent({std::make_pair(loss1, 10)}));
   EXPECT_FALSE(reno.inSlowStart());
   auto newWritableBytes1 = reno.getWritableBytes();
   EXPECT_LT(newWritableBytes1, originalWritableBytes);
@@ -196,8 +188,7 @@ TEST_F(NewRenoTest, TestSteadyStateAck) {
       ackPacketNum1, ackedSize, Clock::now() - std::chrono::milliseconds(10));
   reno.onPacketSent(packet1);
   reno.onPacketAckOrLoss(
-      createAckEvent(ackPacketNum1, ackedSize, packet1.metadata.time),
-      folly::none);
+      createAckEvent(ackPacketNum1, ackedSize, packet1.metadata.time), none);
   EXPECT_FALSE(reno.inSlowStart());
 
   auto newWritableBytes2 = reno.getWritableBytes();
@@ -207,8 +198,7 @@ TEST_F(NewRenoTest, TestSteadyStateAck) {
   auto packet2 = createPacket(ackPacketNum2, ackedSize, Clock::now());
   reno.onPacketSent(packet2);
   reno.onPacketAckOrLoss(
-      createAckEvent(ackPacketNum2, ackedSize, packet2.metadata.time),
-      folly::none);
+      createAckEvent(ackPacketNum2, ackedSize, packet2.metadata.time), none);
   EXPECT_FALSE(reno.inSlowStart());
 
   auto newWritableBytes3 = reno.getWritableBytes();
@@ -248,7 +238,7 @@ TEST_F(NewRenoTest, PersistentCongestion) {
   CongestionController::LossEvent loss;
   loss.persistentCongestion = true;
   loss.addLostPacket(pkt);
-  reno.onPacketAckOrLoss(folly::none, loss);
+  reno.onPacketAckOrLoss(none, loss);
   EXPECT_EQ(
       reno.getWritableBytes(),
       conn.transportSettings.minCwndInMss * conn.udpSendPacketLen);
