@@ -72,7 +72,7 @@ QuicServerWorker::QuicServerWorker(
     // TODO: maxBatchSize is only a good start value when each transport does
     // its own socket writing. If we experiment with multiple transports GSO
     // together, we will need a better value.
-    bufAccessor_ = std::make_unique<SimpleBufAccessor>(
+    bufAccessor_ = std::make_unique<BufAccessor>(
         kDefaultMaxUDPPayload * transportSettings_.maxBatchSize);
     VLOG(10) << "GSO write buf accessor created for ContinuousMemory data path";
   }
@@ -353,6 +353,13 @@ void QuicServerWorker::onDataAvailable(
   // we've flushed it.
   Buf data = std::move(readBuffer_);
 
+  folly::Optional<ReceivedUdpPacket::Timings::SocketTimestampExt>
+      maybeSockTsExt;
+  if (params.ts.has_value()) {
+    maybeSockTsExt =
+        QuicAsyncUDPSocket::convertToSocketTimestampExt(*params.ts);
+  }
+
   if (params.gro <= 0) {
     if (truncated) {
       // This is an error, drop the packet.
@@ -363,6 +370,7 @@ void QuicServerWorker::onDataAvailable(
     QUIC_STATS(statsCallback_, onRead, len);
     ReceivedUdpPacket udpPacket(std::move(data));
     udpPacket.timings.receiveTimePoint = packetReceiveTime;
+    udpPacket.timings.maybeSoftwareTs = maybeSockTsExt;
     udpPacket.tosValue = params.tos;
     handleNetworkData(client, udpPacket);
   } else {
@@ -388,6 +396,7 @@ void QuicServerWorker::onDataAvailable(
         ReceivedUdpPacket udpPacket(std::move(data));
         udpPacket.timings.receiveTimePoint = packetReceiveTime;
         udpPacket.tosValue = params.tos;
+        udpPacket.timings.maybeSoftwareTs = maybeSockTsExt;
         handleNetworkData(client, udpPacket);
         break;
       }
@@ -403,6 +412,7 @@ void QuicServerWorker::onDataAvailable(
       ReceivedUdpPacket udpPacket(std::move(tmp));
       udpPacket.timings.receiveTimePoint = packetReceiveTime;
       udpPacket.tosValue = params.tos;
+      udpPacket.timings.maybeSoftwareTs = maybeSockTsExt;
       handleNetworkData(client, udpPacket);
     }
   }
@@ -741,7 +751,7 @@ PacketDropReason QuicServerWorker::isDstConnIdMisrouted(
   }
 
   const auto& connIdParams = maybeParsedConnIdParam.value();
-  if (connIdParams.hostId != hostId_) {
+  if (connIdParams.hostId != prevHostId_ && connIdParams.hostId != hostId_) {
     VLOG(3) << fmt::format(
         "Dropping packet routed to wrong host, from client={}, routingInfo={},",
         client.describe(),
@@ -1209,6 +1219,7 @@ uint8_t QuicServerWorker::getWorkerId() const noexcept {
 }
 
 void QuicServerWorker::setHostId(uint32_t hostId) noexcept {
+  prevHostId_ = hostId_;
   hostId_ = hostId;
 }
 
