@@ -80,6 +80,10 @@ struct CongestionControlConfig {
   // Whether BBR2 should enable reno coexistence.
   bool enableRenoCoexistence{false};
 
+  // Used by: BBR2
+  // Whether BBR2 paces the initial congestion window.
+  bool paceInitCwnd{true};
+
   // Used by: BBR2
   // Use a different pacing gain during ProbeBW Cruise and Refill.
   // If value < 0, use the default pacing gain.
@@ -390,6 +394,15 @@ struct TransportSettings {
   // QuicBatchingMode::BATCHING_MODE_NONE and DataPathType::ChainedMemory
   // and requires useSockWritableEvents to be enabled.
   bool enableWriterBackpressure{false};
+  // Ack timeout = SRTT * ackTimerFactor
+  double ackTimerFactor{kAckTimerFactor};
+  // If flow control updates should be sent based on time passed since last
+  // update.
+  bool enableFlowControlTimeBasedUpdates{true};
+  // Check if idle timer needs to be triggered manually.
+  bool checkIdleTimerOnWrite{false};
+  // Whether to process callbacks per received packet.
+  bool processCallbacksPerPacket{false};
 };
 
 } // namespace quic
