@@ -102,6 +102,12 @@ DEFINE_uint32(
     max_ack_receive_timestamps_to_send,
     quic::kMaxReceivedPktsTimestampsStored,
     "Controls how many packet receive timestamps the peer should send");
+DEFINE_bool(use_l4s_ecn, false, "Whether to use L4S for ECN marking");
+DEFINE_bool(
+    read_ecn,
+    false,
+    "Whether to read and echo ecn marking from ingress packets");
+DEFINE_uint32(dscp, 0, "DSCP value to use for outgoing packets");
 
 namespace quic {
 namespace tperf {
@@ -443,15 +449,8 @@ class TPerfServer {
       bool overridePacketSize)
       : host_(host),
         port_(port),
-        acceptObserver_(std::make_unique<TPerfAcceptObserver>()),
-        server_(QuicServer::createQuicServer()) {
+        acceptObserver_(std::make_unique<TPerfAcceptObserver>()) {
     eventBase_.setName("tperf_server");
-    server_->setQuicServerTransportFactory(
-        std::make_unique<TPerfServerTransportFactory>(
-            blockSize, numStreams, maxBytesPerStream, dsrEnabled));
-    auto serverCtx = quic::test::createServerCtx();
-    serverCtx->setClock(std::make_shared<fizz::SystemClock>());
-    server_->setFizzContext(serverCtx);
     quic::TransportSettings settings;
     if (useInplaceWrite && gso) {
       settings.dataPathType = DataPathType::ContinuousMemory;
@@ -480,9 +479,28 @@ class TPerfServer {
            kDefaultReceiveTimestampsExponent});
     }
 
+    if (FLAGS_use_l4s_ecn) {
+      settings.enableEcnOnEgress = true;
+      settings.useL4sEcn = true;
+      settings.minBurstPackets = 1;
+      settings.experimentalPacer = true;
+      settings.ccaConfig.onlyGrowCwndWhenLimited = true;
+      settings.ccaConfig.leaveHeadroomForCwndLimited = true;
+    }
+
+    settings.readEcnOnIngress = FLAGS_read_ecn;
+    settings.dscpValue = FLAGS_dscp;
+
+    server_ = QuicServer::createQuicServer(settings);
+    server_->setQuicServerTransportFactory(
+        std::make_unique<TPerfServerTransportFactory>(
+            blockSize, numStreams, maxBytesPerStream, dsrEnabled));
+    auto serverCtx = quic::test::createServerCtx();
+    serverCtx->setClock(std::make_shared<fizz::SystemClock>());
+    server_->setFizzContext(serverCtx);
+
     server_->setCongestionControllerFactory(
         std::make_shared<ServerCongestionControllerFactory>());
-    server_->setTransportSettings(settings);
   }
 
   void start() {
@@ -538,7 +556,7 @@ class TPerfClient : public quic::QuicSocket::ConnectionSetupCallback,
   }
 
   void timeoutExpired() noexcept override {
-    quicClient_->closeNow(folly::none);
+    quicClient_->closeNow(none);
     constexpr double bytesPerMegabit = 131072;
     LOG(INFO) << "Received " << receivedBytes_ << " bytes in "
               << duration_.count() << " seconds.";
@@ -671,7 +689,6 @@ class TPerfClient : public quic::QuicSocket::ConnectionSetupCallback,
     settings.advertisedInitialConnectionFlowControlWindow = window_;
     settings.autotuneReceiveConnFlowControl = autotuneWindow_;
     settings.connectUDP = true;
-    settings.shouldRecvBatch = true;
     settings.shouldUseRecvmmsgForBatchRecv = true;
     settings.maxRecvBatchSize = 64;
     settings.numGROBuffers_ = 64;
@@ -705,6 +722,18 @@ class TPerfClient : public quic::QuicSocket::ConnectionSetupCallback,
       settings.maxBatchSize = 1;
       settings.dataPathType = DataPathType::ContinuousMemory;
     }
+    if (FLAGS_use_l4s_ecn) {
+      settings.enableEcnOnEgress = true;
+      settings.useL4sEcn = true;
+      settings.minBurstPackets = 1;
+      settings.experimentalPacer = true;
+      settings.ccaConfig.onlyGrowCwndWhenLimited = true;
+      settings.ccaConfig.leaveHeadroomForCwndLimited = true;
+    }
+
+    settings.readEcnOnIngress = FLAGS_read_ecn;
+    settings.dscpValue = FLAGS_dscp;
+
     quicClient_->setTransportSettings(settings);
 
     LOG(INFO) << "TPerfClient connecting to " << addr.describe();
